@@ -2,7 +2,7 @@
 package Net::DNSBL::MultiDaemon;
 
 use strict;
-use diagnostics;
+#use diagnostics;
 
 use vars qw(
 	$VERSION @ISA @EXPORT_OK %EXPORT_TAGS *R_Sin
@@ -20,7 +20,7 @@ $D_NOTME     = 0x10; # return received response not for me
 $D_ANSTOP    = 0x20; # clear run OK flag if ANSWER present
 $D_VERBOSE   = 0x40; # verbose debug statements to STDERR
 
-$VERSION = do { my @r = (q$Revision: 0.05 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 0.06 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 @EXPORT_OK = qw(
         run
@@ -63,10 +63,10 @@ use Net::DNS::ToolKit 0.16 qw(
 	get_ns
 );
 use Net::DNS::ToolKit::RR;
-use Net::DNS::ToolKit::Debug qw(
-	print_head
-	print_buf
-);
+#use Net::DNS::ToolKit::Debug qw(
+#	print_head
+#	print_buf
+#);
 
 use Net::DNSBL::Utilities qw(
         s_response 
